#
# spec file for package libgpg-error
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgpg-error
Version:        1.13
Release:        4.19
Summary:        Library That Defines Common Error Values for All GnuPG Components
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.gnupg.org/
Source:         ftp://ftp.gnupg.org/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2
Source1:        ftp://ftp.gnupg.org/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2.sig
# http://www.gnupg.org/signature_key.en.html
Source2:        %name.keyring
Source3:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libtool
#BuildRequires:  gpg-offline

%description
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon, and possibly more in the future.

%package -n libgpg-error0
Summary:        Library That Defines Common Error Values for All GnuPG Components
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      libgpg-error-64bit
%endif
#
Provides:       libgpg-error = %version
Obsoletes:      libgpg-error < %version

%description -n libgpg-error0
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon, and possibly more in the future.

%package devel
Summary:        Development package for libgpg-error
License:        GPL-2.0+ and LGPL-2.1+ and MIT
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libgpg-error0 = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      libgpg-error-devel-64bit
%endif

%description devel
Files needed for software development using libgpg-error.

%prep
%setup -q -n libgpg-error-%version

%build
%configure --disable-static --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm %{buildroot}%{_libdir}/libgpg-error.la
# Drop the lisp stuff, it depends on ASDF and CFFI
# which needs to be packaged first
rm -r %{buildroot}%{_datadir}/common-lisp
%find_lang %{name}

%check
make check %{?_smp_mflags}
%{buildroot}/%{_bindir}/gpg-error-config --libs | grep -q -v "\-lpthread"
%{buildroot}/%{_bindir}/gpg-error-config --mt --libs | grep -q "\-lpthread"

%post -n libgpg-error0 -p /sbin/ldconfig

%postun -n libgpg-error0 -p /sbin/ldconfig

%files -n libgpg-error0 -f %{name}.lang
%defattr(-,root,root)
%{_libdir}/libgpg-error*.so.*

%files devel
%defattr(-,root,root)
%doc README NEWS ChangeLog COPYING.LIB COPYING AUTHORS ABOUT-NLS
%{_datadir}/aclocal/gpg-error.m4
%{_includedir}/*
%{_bindir}/*
%{_libdir}/libgpg-error*.so

%changelog
* Tue Apr 29 2014 vcizek@suse.com
- update to 1.13
  (needed by libgcrypt patches for bnc#856312)
  * Added a portable mutex API.
  * The AM_PATH_GPG_ERROR macro now defines GPG_ERROR_MT_CFLAGS
    and GPG_ERROR_MT_LIBS autoconf output variables for use by
    programs which need gpgrt based thread support.
    gpg-error-config has a new option --mt.
- Interface changes relative to the 1.12 release:
  GPG_ERR_KEY_ON_CARD          NEW.
  GPG_ERR_MAC_ALGO             NEW.
  GPG_ERR_INV_LOCK_OBJ         NEW.
  gpgrt_lock_t                 NEW.
  GPGRT_LOCK_INITIALIZER       NEW.
  GPGRT_LOCK_DEFINE            NEW.
  gpgrt_lock_init              NEW.
  gpgrt_lock_lock              NEW.
  gpgrt_lock_unlock            NEW.
  gpgrt_lock_destroy           NEW.
  gpgrt_yield                  NEW.
- run available tests
* Mon Aug 19 2013 andreas.stieger@gmx.de
- update to 1.12
  * Interface changes relative to the 1.11 release:
  GPG_ERR_NO_CRYPT_CTX         NEW.
  GPG_ERR_WRONG_CRYPT_CTX      NEW.
  GPG_ERR_BAD_CRYPT_CTX        NEW.
  GPG_ERR_CRYPT_CTX_CONFLICT   NEW.
  GPG_ERR_BROKEN_PUBKEY        NEW.
  GPG_ERR_BROKEN_SECKEY        NEW.
- drop unused libgpg-error-nld-build.diff
- drop autoreconv call
* Tue Jun 18 2013 coolo@suse.com
- remove gpg verification from bootstrap packages
* Mon Feb 25 2013 andreas.stieger@gmx.de
- update to 1.11
  * New error source GPG_ERR_SOURCE_ASSUAN for Libassuan related
  errors.
  * New macros GPG_ERROR_VERSION and GPG_ERROR_VERSION_NUMBER.  New
  function gpg_error_check_version.
  * Interface changes relative to the 1.10 release:
  GPG_ERR_NO_KEYSERVER          NEW.
  GPG_ERR_INV_CURVE             NEW.
  GPG_ERR_UNKNOWN_CURVE         NEW.
  GPG_ERR_DUP_KEY               NEW.
  GPG_ERR_AMBIGUOUS             NEW.
  GPG_ERR_SOURCE_ASSUAN         NEW.
  gpg_error_check_version       NEW.
  GPG_ERROR_VERSION             NEW.
  GPG_ERROR_VERSION_NUMBER      NEW.
- add offline verification of source signature
* Sat Feb  2 2013 coolo@suse.com
- update license to new format
* Sun Feb 12 2012 crrodriguez@opensuse.org
- Move libraries back to %%{_libdir}, /usr merge project
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct  2 2011 crrodriguez@opensuse.org
-  Update to version 1.10
  * Define GPG_ERR_ENABLE_ERRNO_MACROS.
  * Add GPG_ERR_NOT_INITIALIZED.
  * Add GPG_ERR_MISSING_ISSUER_CERT
* Fri Dec  3 2010 puzel@novell.com
- update to version 1.9
  * New function gpg_err_deinit.
  * Interface changes relative to the 1.8 release:
  GPG_ERR_MISSING_KEY           NEW
  GPG_ERR_TOO_MANY              NEW
  GPG_ERR_LIMIT_REACHED         NEW
  gpg_err_deinit                NEW
- clean up specfile
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Tue Aug 17 2010 puzel@novell.com
- update to version 1.8
  * New option --list for gpg-error.
  * Interface changes relative to the 1.7 release:
  GPG_ERR_NOT_ENABLED           NEW
  GPG_ERR_SOURCE_G13            NEW
  GPG_ERR_NO_ENGINE             NEW
  gpg_err_set_errno             NEW
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Jun  1 2009 puzel@suse.cz
- update to version 1.7
  * Minor fixes and a few new error codes.
  * Interface changes relative to the 1.6 release:
  GPG_ERR_NOT_OPERATIONAL       NEW
  GPG_ERR_NO_PASSPHRASE         NEW
  GPG_ERR_NO_PIN                NEW
* Fri Feb 20 2009 crrodriguez@suse.de
- remove static libraries, there is no reason to use them as
  shared libraries live in /%%{_lib}
* Thu Jan 29 2009 olh@suse.de
- obsolete libgpg-error-XXbit in the library subpackage
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Nov 21 2007 mkoenig@suse.de
- update to version 1.6
  * Minor build system fixes
  * gpg-error has a new option --version
  * Interface changes relative to the 1.4 release:
    GPG_ERR_UNFINISHED            NEW
    GPG_ERR_SOURCE_GPA            NEW
    GPG_ERR_SOURCE_KLEO           NEW
- package branch to conform shlib policy:
  libgpg-error0
* Wed Dec 13 2006 mkoenig@suse.de
- get rid of .la file and fix devel so link
* Tue Dec  5 2006 mkoenig@suse.de
- move shared lib to /%%_lib
* Tue Sep 19 2006 mkoenig@suse.de
- update to version 1.4:
  * New error codes for the Assuan IPC library.
  * New error code GPG_ERR_MISSING_ERRNO
  * New error source GPG_ERR_SOURCE_ANY
  * New convenience functions gpg_err_code_from_syserror and
  gpg_error_from_syserror
* Thu Jul 13 2006 mskibbe@suse.de
- add autoreconf --force ( includes the missing -fPIC option while
  build )
* Wed Jul 12 2006 mskibbe@suse.de
- update to version 1.3 which
  o includes fixes in Makefiles
  o fix cast problems
  o include utf8 functions
  o add some languages
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jun 23 2005 hvogel@suse.de
- require libgpg-error
- add %%clean section
* Thu Oct 14 2004 hvogel@suse.de
- update to version 1.0
* Mon Sep 27 2004 hvogel@suse.de
- fixed ac-quotation of gpg-error.m4
* Mon Jul 19 2004 hvogel@suse.de
- correct nld_build if statement
* Wed Jul 14 2004 adrian@suse.de
- create -devel subpackage
- prepare for NLD
* Mon May 24 2004 ro@suse.de
- added return value to non-void function (main)
* Wed May 19 2004 hvogel@suse.de
- update to version 0.7
* Tue Feb 17 2004 hvogel@suse.de
- initial package, version 0.6
